#!/bin/bash

DOCKER_IMAGE=pandoc/core:3.0
TOOLS_DOCKER_IMAGE=generatechangemarks:master

echo "\n------ Checking for docker image --------"
docker pull "$DOCKER_IMAGE"

echo "------ Removing previous outputs --------"
rm **/*.docx

echo "------ Parsing repo URL --------"

HOST_URL=$(echo $1 | cut -d'/' -f 1-3)
PROJECT_NAME=$(echo $1 | cut -d'/' -f 5- | cut -d'.' -f 1)
echo "HOST URL:" $HOST_URL
echo "PROJECT NAME:" $PROJECT_NAME
echo "TAG NAME:" $2

echo "------ Getting .md file(s) ------"
# If there are no .md files, then simply exit
ls | grep -q 'md'
specs=$?
if [ ! $specs ] ; then 
    echo "-- No Markdown files."
    exit 0
fi

for i in *.md ;  do
	echo "\n------ Preparaing spec --------" 
	docker run --rm -v $(pwd):/tmp/ -u $(id -u):$(id -g) "$TOOLS_DOCKER_IMAGE" pandocFilter -o "/tmp/" "/tmp/$i"
	echo "\n------ Publishing spec --------" 
	docker run --rm -v $(pwd):/data -u $(id -u):$(id -g) "$DOCKER_IMAGE" "/data/$i" -f markdown -t docx --reference-doc "Spec-template.docx" -o "${PROJECT_NAME}_${2}.docx" 
done


exit 0