#
#	updateIndex.py
#
#	Script to update index.htm file on Pages.
#
#	(c) 2023 by Miguel Angel Reina Ortega
#	License: BSD 3-Clause License. See the LICENSE file for further details.
#
from bs4 import BeautifulSoup
import argparse, os

def updateIndex(args:argparse.Namespace) -> None:
    
    # Check if index.htm exists
    if not os.path.exists('public/index.html'):
        print("'index.html' does not exist yet, using template")
        with open(args.indexTemplate, 'r', encoding='utf-8') as file:
            html_content = file.read()
    else:
        # Read index HTML
        with open('public/index.html', 'r', encoding='utf-8') as file:
            html_content = file.read()

    # Analyze index content with BeautifulSoup
    soup = BeautifulSoup(html_content, 'html.parser')

    # Find document list
    # Assume there's a list (<ul>) with id "document-list"
    document_list = soup.find('ul', id='document-list')

    # Add the new element <li> for the new document
    if args.documentLink is not None and args.documentName is not None:
        li = soup.new_tag('li')
        a = soup.new_tag('a', href=args.documentLink)
        a.string = args.documentName
        li.append(a)
        document_list.append(li)

    # Guarda el archivo HTML actualizado
    with open('public/index.html', 'w', encoding='utf-8') as file:
        file.write(str(soup))

    print("Index.html updated")
			


if __name__ == '__main__':

    # Parse command line arguments
    parser = argparse.ArgumentParser(formatter_class=argparse.ArgumentDefaultsHelpFormatter)
    parser.add_argument('documentName', help = 'Document name to add to the list')
    parser.add_argument('documentLink', help = 'Document location to add to the list')
    parser.add_argument('indexTemplate', help = 'Index template document')
    args = parser.parse_args()

    updateIndex(args)

